@@ -1,18 +1,7 @@
-/***************************************************************************
-                          dlgspecchar.cpp  -  description
-                             -------------------
-   copyright       : (C) 2003-2009 Peter Hedlund <peter.hedlund@kdemail.net>
-
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2003-2009 Peter Hedlund <peter.hedlund@kdemail.net>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "dlgspecchar.h"
 
@@ -67,12 +56,12 @@ QChar DlgSpecChar::chr()
 
 void DlgSpecChar::slotDoubleClicked()
 {
-  emit insertChar(chr());
+  Q_EMIT insertChar(chr());
   closeDialog();
 }
 
 void DlgSpecChar::slotUser1( )
 {
-  emit insertChar(chr());
+  Q_EMIT insertChar(chr());
   closeDialog();
 }
