@@ -1,19 +1,7 @@
-/***************************************************************************
-                                kwordquiz.cpp
-                             -------------------
-    begin         : Wed Jul 24 20:12:30 PDT 2002
-    copyright     : (C) 2002-2010 Peter Hedlund <peter.hedlund@kdemail.net>
-
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2002-2010 Peter Hedlund <peter.hedlund@kdemail.net>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "kwordquiz.h"
 
@@ -1296,7 +1284,7 @@ void KWordQuizApp::slotApplyPreferences()
   editUnmarkBlank->setEnabled(Prefs::enableBlanks());
   m_tableView->reset();
   updateSpecialCharIcons();
-  emit settingsChanged();
+  Q_EMIT settingsChanged();
 }
 
 void KWordQuizApp::updateSpecialCharIcons()
